.. EEmiLib documentation master file, created by
   sphinx-quickstart on Tue Jul  2 19:10:08 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to EEmiLib's documentation!
===================================

.. toctree::
   :maxdepth: 1
   :caption: Contents
   :titlesonly:
   :glob:

   manual/quick_start
   manual/notations
   manual/models
   manual/future_updates
   manual/bibliography
   API reference <eemilib/modules>

.. include:: ../README.md
   :parser: myst_parser.sphinx_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

